#!/usr/bin/python

#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are
#  met:
#  
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following disclaimer
#    in the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of the  nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
#  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
#  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
#  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  



class LcdBackLightManager:
    """
    A simple class to manage the LCD back light
    """
    def __init__(self, lcd, maxCnt):
        """
        ctor: record the maximum number of unread messages that we can have
        before the LCD backlight goes red
        """
        self.lcd = lcd
        self.maxCnt = maxCnt
        
        # Look table of RGB values 
        self.backLightColors = (
            (0, 255, 10),
            (50, 200, 10),
            (80, 180,  20),
            (120, 100,  20),
            (150, 80, 30),
            (180, 65, 80),
            (200, 50, 20),
            (255, 0, 10)
        )
        self.length = len(self.backLightColors)

    def setTemp(self, temp):
        """
        Calculates the percentage of unread mails in the inbox and sets the
        back light accrodingly.
        The percentage is calculated against the maxCnt.
        """
        idx = (temp/float(self.maxCnt))*self.length
        idx = int(idx)
        if (idx > self.length):
            idx = self.length-1

        print idx
        
        self.lcd.setColor(self.backLightColors[idx][0],
                     self.backLightColors[idx][1],
                     self.backLightColors[idx][2])

    def setMaxCnt(self, maxCnt):
        """
        setter method for maxCnt
        """
        self.maxCnt = maxCnt

    def getMaxCnt(self):
        """
        getter method for maxCnt
        """
        return self.maxCnt



import pyupm_i2clcd
import time
if __name__ == '__main__':
    lcd = pyupm_i2clcd.Jhd1313m1(0, 0x3E, 0x62)
    obj = LcdBackLightManager(lcd, 50)
    i=0;

    while i<50:
        obj.setTemp(i)
        i += 1
        time.sleep(1)
